/*****************************************************************

docbegin:


*  Name of source file:         j_ima_mosaic.h

*  Version of source file:      8.0.0

*  Parent component:            None

*  Programmer:                  Jérôme Chenevez

*  Affiliation:                 National Space Institute, Technical University of Denmark

*  Contact address:             Juliane Maries Vej 30
*                               DK-2100 Copenhagen, Denmark
*                               Phone: +45 35325703  FAX: +45 35362475
*                               jerome@space.dtu.dk

*  Purpose:                     Read a set of sky images for an observation group
*                               and produce the weighted mosaic image

*  Origin date:                 20041206

*  Update history:              5.0    20041206  Copied from mosaic_weight-5.2
*				5.0.1  20050419  Now also combine iros input images in cnts/cm2/s
*				5.0.2  20050603  Urgent fixes for OSA 5 by SP 
*                                                SPRs: 4174 (part.), 4176 (part.), 4190, 4191, 4205
*				5.0.3  20050620  Fix SPRs 4174, 4175 4176, 4222
*                               5.0.4  20050622  Fix SPR 4244
*                               5.1.0  20051014  SCREW 1772 : base the image selection on VARIANCE maps
*                               6.0.0  20060329  Fix SPR 4377: problem with the energy selection resolved
*						 SCREW 1850 : Use correct WCS routines allowing large mosaics
*                               6.0.1  20060908  Fix SPR 4301 : new parameter dolBPL
*                               6.0.2  20060915  SCREW 1918 : Copy j_ima_iros IMATYPE keywords to output
*                               6.0.3  20060927  SCREW 1929 : Gather all energy bands and mosaic products in one single output file
*                               6.0.4  20061110  SPR 4603 : Copy correct input image units (cnts/dm2/s) to output
*                               6.0.5  20061206  SPR 4625 : Some selection strings defined too short
*                                                SPR 4632 : Allow variable number of input images by dynamic memory allocation
*                               7.0.0  20070707  SCREW 2008 Allow mixing of JMX1 and JMX2 mosaics
*						 SCREW 2024 Optionnal printing of input ScW list in the HEADERs of mosaic file
*                               7.0.1  20070820  SPR 4711: Allow empty dolBPL when combining Jem-X mosaics
*                               7.0.2  20070824  SPR 4714: Initialisations previous to DALallocateDataBuffer
*                               8.0.0  20090106  SCREW 2102: Copy of PSFSIGMA keyword from JMXi-SKY-IMA
*                                                SCREW 2105: Coord. transfo. keywords CD are now energy dependent

*  Type of element:             Headerfile

*  Part of package:             j_ima_mosaic

docend:

***********************************************************************************************************/

#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>
#include <jemx.h>
#include <isdc.h>
#include <dal3aux.h>
#include <wcs.h>

#define COMPONENT_VERSION     "8.0.0"         /*  Version number  */
#define COMPONENT_NAME        "j_ima_mosaic"  /*  Name of this component  */

#define J_MOS_BAD_INSTRUMENT (J_ERROR_CODE_START - 1)

#define NB_E 51             /* Number of Energy bands or slices in bpl-DMAP array (default) */
#define XD 511              /* X dim. of bpl-DMAP array (default) */
#define YD 511              /* Y dim. of bpl-DMAP array (default) */
#define MOSAICSIZE 4000000 /* Maximum mosaic images size in pixels */
#define J_MOSA_EPSILON  1.0E-10	/* Machine epsilon for float zero testing */

/* Declarations of  big arrays */
  int mark[MOSAICSIZE];
  double pval_o[MOSAICSIZE], var_o[MOSAICSIZE], t_exp[MOSAICSIZE], v_exp[MOSAICSIZE], weight[MOSAICSIZE];

/* ****************************************************************************************************** */

/*  Function Prototype Definitions  */

int j_ima_mosaic_params(
                   char *groupDOL,
                   char *imSelect,
                   char *dolBPL,
                   char *mosaic,
                   double *radius,
                   double *emin,
                   double *emax,
                   double *diamout,
                   double *cdelt, 
                   double *centerA,
                   double *centerD,
                   int *plot_T, 
                   int *plot_I,
                   int *plot_V,
                   int *plot_S,
                   int *liScW,
                   int *comos,
            /*     int *clobber,                 Boolean, erase old results?  */
                   int *chatter,              /* Level of debugging output    */
                   int status );              /* Status flag                  */

int j_ima_mosaic_work(
                   char *groupDOL,
                   char *imSelect,
                   char *dolBPL,
                   char *mosaic,
                   double radius,
                   double emin,
                   double emax,
                   double diamout,
                   double cdelt, 
                   double centerA,
                   double centerD,
                   int plot_T, 
                   int plot_I,
                   int plot_V,
                   int plot_S,
                   int liScW,
                   int comos,
              /*   int clobber,                 Boolean, erase old results?  */
                   int chatter,              /* Level of debugging output    */
                   int status );             /* Status flag                  */


Instrument instrumentGetCode(const char *instName);
